[![PyPI version](https://badge.fury.io/py/onemetric.svg)](https://badge.fury.io/py/onemetric)
![PyPI - Downloads](https://img.shields.io/pypi/dm/onemetric)
![PyPI - License](https://img.shields.io/pypi/l/onemetric)
[![codecov](https://codecov.io/gh/SkalskiP/onemetric/branch/master/graph/badge.svg?token=ZFSEYF9WN4)](https://codecov.io/gh/SkalskiP/onemetric)
![tests](https://github.com/SkalskiP/onemetric/actions/workflows/tests.yml/badge.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/onemetric)

<h1 align="center">onemetric</h1>

<p align="center"> 
    <img width="150" src="https://onemetric-images.s3.eu-central-1.amazonaws.com/favicon.png" alt="Logo">
</p>

## Installation

```terminal
pip install onemetric
```

## Documentation

The official documentation is hosted on Github Pages: https://skalskip.github.io/onemetric

## Contribute

Feel free to file [issues](https://github.com/SkalskiP/onemetric/issues) or [pull requests](https://github.com/SkalskiP/onemetric/pulls). Let us know what metrics should be part of onemetric!

## Citation

Please cite onemetric in your publications if this is useful for your research. Here is an example BibTeX entry:

```BibTeX
@MISC{onemetric,
   author = {Piotr Skalski},
   title = {{onemetric}},
   howpublished = "\url{https://github.com/SkalskiP/onemetric/}",
   year = {2021},
}
```

## License

This project is licensed under the BSD 3 - see the [LICENSE][1] file for details.

## Acknowledgements

Building onemetric would have been much more difficult if not for the efforts and persistence of many open-source developers. Their ideas were the help and inspiration in creating this library. **Thank you!**

1. Confusion Matrix for Object Detection [link](2) by [kaanakan](3).
2. Mean Average Precision for Object Detection [link](4) by [bes-dev](5).
3. YOLOv3 in PyTorch [link](6) by [ultralytics](7).

[1]: https://github.com/SkalskiP/onemetric/blob/master/LICENSE
[2]: https://github.com/kaanakan/object_detection_confusion_matrix
[3]: https://github.com/kaanakan
[4]: https://github.com/bes-dev/mean_average_precision
[5]: https://github.com/bes-dev
[6]: https://github.com/ultralytics/yolov3
[7]: https://github.com/ultralytics
